aboutsummaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/imports/controls/Dial.qml (renamed from src/imports/extras/Dial.qml)3
-rw-r--r--src/imports/controls/Drawer.qml (renamed from src/imports/extras/Drawer.qml)3
-rw-r--r--src/imports/controls/SwipeView.qml (renamed from src/imports/extras/SwipeView.qml)4
-rw-r--r--src/imports/controls/Tumbler.qml (renamed from src/imports/extras/Tumbler.qml)3
-rw-r--r--src/imports/controls/controls.pro16
-rw-r--r--src/imports/controls/doc/images/qtquickcontrols2-dial-background.png (renamed from src/imports/extras/doc/images/qtquickextras2-dial-background.png)bin3286 -> 3286 bytes
-rw-r--r--src/imports/controls/doc/images/qtquickcontrols2-dial-handle.png (renamed from src/imports/extras/doc/images/qtquickextras2-dial-handle.png)bin3538 -> 3538 bytes
-rw-r--r--src/imports/controls/doc/images/qtquickcontrols2-tumbler-background.png (renamed from src/imports/extras/doc/images/qtquickextras2-tumbler-background.png)bin1025 -> 1025 bytes
-rw-r--r--src/imports/controls/doc/images/qtquickcontrols2-tumbler-contentItem.png (renamed from src/imports/extras/doc/images/qtquickextras2-tumbler-contentItem.png)bin1025 -> 1025 bytes
-rw-r--r--src/imports/controls/doc/images/qtquickcontrols2-tumbler-delegate.png (renamed from src/imports/extras/doc/images/qtquickextras2-tumbler-delegate.png)bin1047 -> 1047 bytes
-rw-r--r--src/imports/controls/doc/images/qtquickcontrols2-tumbler-wrap.gif (renamed from src/imports/extras/doc/images/qtquickextras2-tumbler-wrap.gif)bin38931 -> 38931 bytes
-rw-r--r--src/imports/controls/doc/qtquickcontrols2.qdocconf2
-rw-r--r--src/imports/controls/doc/src/qtquickcontrols2-customize.qdoc42
-rw-r--r--src/imports/controls/doc/src/qtquickcontrols2-index.qdoc4
-rw-r--r--src/imports/controls/qquickdial.cpp (renamed from src/imports/extras/qquickdial.cpp)26
-rw-r--r--src/imports/controls/qquickdial_p.h (renamed from src/imports/extras/qquickdial_p.h)2
-rw-r--r--src/imports/controls/qquickdrawer.cpp (renamed from src/imports/extras/qquickdrawer.cpp)2
-rw-r--r--src/imports/controls/qquickdrawer_p.h (renamed from src/imports/extras/qquickdrawer_p.h)2
-rw-r--r--src/imports/controls/qquickswipeview.cpp (renamed from src/imports/extras/qquickswipeview.cpp)10
-rw-r--r--src/imports/controls/qquickswipeview_p.h (renamed from src/imports/extras/qquickswipeview_p.h)2
-rw-r--r--src/imports/controls/qquicktumbler.cpp (renamed from src/imports/extras/qquicktumbler.cpp)18
-rw-r--r--src/imports/controls/qquicktumbler_p.h (renamed from src/imports/extras/qquicktumbler_p.h)2
-rw-r--r--src/imports/controls/qtquickcontrols2plugin.cpp14
-rw-r--r--src/imports/extras/doc/images/.directory4
-rw-r--r--src/imports/extras/doc/qtquickextras2.qdocconf47
-rw-r--r--src/imports/extras/doc/src/qtquickextras2-customize.qdoc82
-rw-r--r--src/imports/extras/doc/src/qtquickextras2-index.qdoc49
-rw-r--r--src/imports/extras/doc/src/qtquickextras2-overview.qdoc53
-rw-r--r--src/imports/extras/doc/src/qtquickextras2.qdoc44
-rw-r--r--src/imports/extras/extras.pri17
-rw-r--r--src/imports/extras/extras.pro23
-rw-r--r--src/imports/extras/plugins.qmltypes67
-rw-r--r--src/imports/extras/qmldir3
-rw-r--r--src/imports/extras/qtquickextras2plugin.cpp74
-rw-r--r--src/imports/imports.pro1
35 files changed, 110 insertions, 509 deletions
diff --git a/src/imports/extras/Dial.qml b/src/imports/controls/Dial.qml
index fbf2807f..fcca2066 100644
--- a/src/imports/extras/Dial.qml
+++ b/src/imports/controls/Dial.qml
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing/
**
-** This file is part of the Qt Quick Extras module of the Qt Toolkit.
+** This file is part of the Qt Quick Controls module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
@@ -36,7 +36,6 @@
import QtQuick 2.6
import QtQuick.Controls 2.0
-import QtQuick.Extras 2.0
AbstractDial {
id: control
diff --git a/src/imports/extras/Drawer.qml b/src/imports/controls/Drawer.qml
index 504fec6b..57db687d 100644
--- a/src/imports/extras/Drawer.qml
+++ b/src/imports/controls/Drawer.qml
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing/
**
-** This file is part of the Qt Quick Extras module of the Qt Toolkit.
+** This file is part of the Qt Quick Controls module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
@@ -36,7 +36,6 @@
import QtQuick 2.6
import QtQuick.Controls 2.0
-import QtQuick.Extras 2.0
AbstractDrawer {
id: control
diff --git a/src/imports/extras/SwipeView.qml b/src/imports/controls/SwipeView.qml
index 4ed74f43..63274f20 100644
--- a/src/imports/extras/SwipeView.qml
+++ b/src/imports/controls/SwipeView.qml
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing/
**
-** This file is part of the Qt Quick Extras module of the Qt Toolkit.
+** This file is part of the Qt Quick Controls module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
@@ -35,7 +35,7 @@
****************************************************************************/
import QtQuick 2.6
-import QtQuick.Extras 2.0
+import QtQuick.Controls 2.0
AbstractSwipeView {
id: control
diff --git a/src/imports/extras/Tumbler.qml b/src/imports/controls/Tumbler.qml
index 7dc7ba1f..500d59db 100644
--- a/src/imports/extras/Tumbler.qml
+++ b/src/imports/controls/Tumbler.qml
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing/
**
-** This file is part of the Qt Quick Extras module of the Qt Toolkit.
+** This file is part of the Qt Quick Controls module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
@@ -36,7 +36,6 @@
import QtQuick 2.6
import QtQuick.Controls 2.0
-import QtQuick.Extras 2.0
AbstractTumbler {
id: control
diff --git a/src/imports/controls/controls.pro b/src/imports/controls/controls.pro
index ddf85666..efea03ef 100644
--- a/src/imports/controls/controls.pro
+++ b/src/imports/controls/controls.pro
@@ -15,6 +15,8 @@ QML_FILES = \
BusyIndicator.qml \
Button.qml \
CheckBox.qml \
+ Dial.qml \
+ Drawer.qml \
Frame.qml \
GroupBox.qml \
Label.qml \
@@ -26,21 +28,31 @@ QML_FILES = \
Slider.qml \
StackView.qml \
Switch.qml \
+ SwipeView.qml \
TabBar.qml \
TabButton.qml \
TextArea.qml \
TextField.qml \
ToggleButton.qml \
ToolBar.qml \
- ToolButton.qml
+ ToolButton.qml \
+ Tumbler.qml
HEADERS += \
+ $$PWD/qquickdial_p.h \
+ $$PWD/qquickdrawer_p.h \
+ $$PWD/qquickswipeview_p.h \
$$PWD/qquicktheme_p.h \
- $$PWD/qquickthemedata_p.h
+ $$PWD/qquickthemedata_p.h \
+ $$PWD/qquicktumbler_p.h
SOURCES += \
+ $$PWD/qquickdial.cpp \
+ $$PWD/qquickdrawer.cpp \
+ $$PWD/qquickswipeview.cpp \
$$PWD/qquicktheme.cpp \
$$PWD/qquickthemedata.cpp \
+ $$PWD/qquicktumbler.cpp \
$$PWD/qtquickcontrols2plugin.cpp
RESOURCES += \
diff --git a/src/imports/extras/doc/images/qtquickextras2-dial-background.png b/src/imports/controls/doc/images/qtquickcontrols2-dial-background.png
index 38fad583..38fad583 100644
--- a/src/imports/extras/doc/images/qtquickextras2-dial-background.png
+++ b/src/imports/controls/doc/images/qtquickcontrols2-dial-background.png
Binary files differ
diff --git a/src/imports/extras/doc/images/qtquickextras2-dial-handle.png b/src/imports/controls/doc/images/qtquickcontrols2-dial-handle.png
index e6fd8cdc..e6fd8cdc 100644
--- a/src/imports/extras/doc/images/qtquickextras2-dial-handle.png
+++ b/src/imports/controls/doc/images/qtquickcontrols2-dial-handle.png
Binary files differ
diff --git a/src/imports/extras/doc/images/qtquickextras2-tumbler-background.png b/src/imports/controls/doc/images/qtquickcontrols2-tumbler-background.png
index aa736615..aa736615 100644
--- a/src/imports/extras/doc/images/qtquickextras2-tumbler-background.png
+++ b/src/imports/controls/doc/images/qtquickcontrols2-tumbler-background.png
Binary files differ
diff --git a/src/imports/extras/doc/images/qtquickextras2-tumbler-contentItem.png b/src/imports/controls/doc/images/qtquickcontrols2-tumbler-contentItem.png
index aa736615..aa736615 100644
--- a/src/imports/extras/doc/images/qtquickextras2-tumbler-contentItem.png
+++ b/src/imports/controls/doc/images/qtquickcontrols2-tumbler-contentItem.png
Binary files differ
diff --git a/src/imports/extras/doc/images/qtquickextras2-tumbler-delegate.png b/src/imports/controls/doc/images/qtquickcontrols2-tumbler-delegate.png
index 77c51efd..77c51efd 100644
--- a/src/imports/extras/doc/images/qtquickextras2-tumbler-delegate.png
+++ b/src/imports/controls/doc/images/qtquickcontrols2-tumbler-delegate.png
Binary files differ
diff --git a/src/imports/extras/doc/images/qtquickextras2-tumbler-wrap.gif b/src/imports/controls/doc/images/qtquickcontrols2-tumbler-wrap.gif
index 2a7e435d..2a7e435d 100644
--- a/src/imports/extras/doc/images/qtquickextras2-tumbler-wrap.gif
+++ b/src/imports/controls/doc/images/qtquickcontrols2-tumbler-wrap.gif
Binary files differ
diff --git a/src/imports/controls/doc/qtquickcontrols2.qdocconf b/src/imports/controls/doc/qtquickcontrols2.qdocconf
index 9e613328..b4d17791 100644
--- a/src/imports/controls/doc/qtquickcontrols2.qdocconf
+++ b/src/imports/controls/doc/qtquickcontrols2.qdocconf
@@ -23,7 +23,7 @@ qhp.QtQuickControls2.subprojects.qtquickcontrols2qmltypes.indexTitle = Qt Quick
qhp.QtQuickControls2.subprojects.qtquickcontrols2qmltypes.selectors = qmlclass
qhp.QtQuickControls2.subprojects.qtquickcontrols2qmltypes.sortPages = true
-depends = qtcore qtgui qtdoc qtqml qtquick qtquicklayouts qtquickdialogs qtquickcontrols qtquickextras2
+depends = qtcore qtgui qtdoc qtqml qtquick qtquicklayouts qtquickdialogs qtquickcontrols
# Specify the install path under QT_INSTALL_EXAMPLES
# Examples will be installed under quick/controls - 'controls' subdirectory
diff --git a/src/imports/controls/doc/src/qtquickcontrols2-customize.qdoc b/src/imports/controls/doc/src/qtquickcontrols2-customize.qdoc
index b099b482..e554b202 100644
--- a/src/imports/controls/doc/src/qtquickcontrols2-customize.qdoc
+++ b/src/imports/controls/doc/src/qtquickcontrols2-customize.qdoc
@@ -95,6 +95,23 @@
\snippet CheckBox.qml indicator
+ \section1 Customizing Dial
+
+ Dial consists of two visual items: \l {Control::background}{background}
+ and \l {Dial::handle}{handle}.
+
+ \section3 Background
+
+ \image qtquickcontrols2-dial-background.png
+
+ \snippet Dial.qml background
+
+ \section3 Indicator
+
+ \image qtquickcontrols2-dial-handle.png
+
+ \snippet Dial.qml handle
+
\section1 Customizing Frame
@@ -370,4 +387,29 @@
\image qtquickcontrols2-toolbutton-label.png
\snippet ToolButton.qml label
+
+ \section1 Customizing Tumbler
+
+ Tumbler consists of three visual items:
+ \l {Control::background}{background},
+ \l {Control::contentItem}{contentItem}, and
+ \l {Tumbler::delegate}{delegate}.
+
+ \section3 Background
+
+ \image qtquickcontrols2-tumbler-background.png
+
+ Tumbler has no background item by default.
+
+ \section3 Content Item
+
+ \image qtquickcontrols2-tumbler-contentItem.png
+
+ \snippet Tumbler.qml contentItem
+
+ \section3 Delegate
+
+ \image qtquickcontrols2-tumbler-delegate.png
+
+ \snippet Tumbler.qml delegate
*/
diff --git a/src/imports/controls/doc/src/qtquickcontrols2-index.qdoc b/src/imports/controls/doc/src/qtquickcontrols2-index.qdoc
index eefd6c3a..d6d13cae 100644
--- a/src/imports/controls/doc/src/qtquickcontrols2-index.qdoc
+++ b/src/imports/controls/doc/src/qtquickcontrols2-index.qdoc
@@ -229,7 +229,7 @@
\li \l [QtQuickControls2] {Slider}
\row
\li \l [QtQuickControls] {SpinBox}
- \li No equivalent; see \l [QtQuickExtras2] {Tumbler} instead.
+ \li No equivalent; see \l [QtQuickControls2] {Tumbler} instead.
\row
\li \l [QtQuickControls] {Stack},
\l [QtQuickControls] {StackView},
@@ -245,7 +245,7 @@
\li \l [QtQuickControls] {Tab},
\l [QtQuickControls] {TabView}
\li \l [QtQuickControls2] {TabBar} in combination with, for example,
- \l [QtQuickExtras2] {SwipeView}.
+ \l [QtQuickControls2] {SwipeView}.
\row
\li \l [QtQuickControls] {TableView}
\li No equivalent
diff --git a/src/imports/extras/qquickdial_p.h b/src/imports/controls/qquickdial_p.h
index 0b5cda35..a31ad09f 100644
--- a/src/imports/extras/qquickdial_p.h
+++ b/src/imports/controls/qquickdial_p.h
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing/
**
-** This file is part of the Qt Quick Extras module of the Qt Toolkit.
+** This file is part of the Qt Quick Controls module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
diff --git a/src/imports/extras/qquickdrawer.cpp b/src/imports/controls/qquickdrawer.cpp
index 1bb9c6f6..23988432 100644
--- a/src/imports/extras/qquickdrawer.cpp
+++ b/src/imports/controls/qquickdrawer.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing/
**
-** This file is part of the Qt Quick Extras module of the Qt Toolkit.
+** This file is part of the Qt Quick Controls module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
diff --git a/src/imports/extras/qquickdrawer_p.h b/src/imports/controls/qquickdrawer_p.h
index 00af2164..1fd8b21a 100644
--- a/src/imports/extras/qquickdrawer_p.h
+++ b/src/imports/controls/qquickdrawer_p.h
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing/
**
-** This file is part of the Qt Quick Extras module of the Qt Toolkit.
+** This file is part of the Qt Quick Controls module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
diff --git a/src/imports/extras/qquickswipeview_p.h b/src/imports/controls/qquickswipeview_p.h
index 89d344ef..e7e1600c 100644
--- a/src/imports/extras/qquickswipeview_p.h
+++ b/src/imports/controls/qquickswipeview_p.h
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing/
**
-** This file is part of the Qt Quick Extras module of the Qt Toolkit.
+** This file is part of the Qt Quick Controls module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
diff --git a/src/imports/extras/qquicktumbler_p.h b/src/imports/controls/qquicktumbler_p.h
index 948382e4..46c683e8 100644
--- a/src/imports/extras/qquicktumbler_p.h
+++ b/src/imports/controls/qquicktumbler_p.h
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing/
**
-** This file is part of the Qt Quick Extras module of the Qt Toolkit.
+** This file is part of the Qt Quick Controls module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
diff --git a/src/imports/controls/qtquickcontrols2plugin.cpp b/src/imports/controls/qtquickcontrols2plugin.cpp
index fcc263a8..f572590c 100644
--- a/src/imports/controls/qtquickcontrols2plugin.cpp
+++ b/src/imports/controls/qtquickcontrols2plugin.cpp
@@ -60,6 +60,10 @@
#include <QtQuickTemplates/private/qquicktogglebutton_p.h>
#include <QtQuickTemplates/private/qquicktoolbar_p.h>
#include <QtQuickTemplates/private/qquicktoolbutton_p.h>
+#include "qquickdial_p.h"
+#include "qquickdrawer_p.h"
+#include "qquickswipeview_p.h"
+#include "qquicktumbler_p.h"
#include "qquicktheme_p.h"
void initResources()
@@ -83,14 +87,22 @@ void QtQuickControls2Plugin::registerTypes(const char *uri)
{
qmlRegisterUncreatableType<QQuickThemeAttached>(uri, 2, 0, "Theme", "Theme is an attached property");
+ qmlRegisterType<QQuickDial>(uri, 2, 0, "AbstractDial");
+ qmlRegisterType<QQuickDrawer>(uri, 2, 0, "AbstractDrawer");
qmlRegisterType<QQuickExclusiveGroup>(uri, 2, 0, "ExclusiveGroup");
qmlRegisterType<QQuickExclusiveGroupAttached>();
+ qmlRegisterType<QQuickSwipeView>(uri, 2, 0, "AbstractSwipeView");
+ qmlRegisterType<QQuickSwipeViewAttached>();
+ qmlRegisterType<QQuickTumbler>(uri, 2, 0, "AbstractTumbler");
+ qmlRegisterType<QQuickTumblerAttached>();
QDir baseDir(baseUrl().toLocalFile());
qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("ApplicationWindow.qml"))), uri, 2, 0, "ApplicationWindow");
qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("BusyIndicator.qml"))), uri, 2, 0, "BusyIndicator");
qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("Button.qml"))), uri, 2, 0, "Button");
qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("CheckBox.qml"))), uri, 2, 0, "CheckBox");
+ qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("Dial.qml"))), uri, 2, 0, "Dial");
+ qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("Drawer.qml"))), uri, 2, 0, "Drawer");
qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("Frame.qml"))), uri, 2, 0, "Frame");
qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("GroupBox.qml"))), uri, 2, 0, "GroupBox");
qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("Label.qml"))), uri, 2, 0, "Label");
@@ -101,6 +113,7 @@ void QtQuickControls2Plugin::registerTypes(const char *uri)
qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("ScrollIndicator.qml"))), uri, 2, 0, "ScrollIndicator");
qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("Slider.qml"))), uri, 2, 0, "Slider");
qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("StackView.qml"))), uri, 2, 0, "StackView");
+ qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("SwipeView.qml"))), uri, 2, 0, "SwipeView");
qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("Switch.qml"))), uri, 2, 0, "Switch");
qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("TabBar.qml"))), uri, 2, 0, "TabBar");
qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("TabButton.qml"))), uri, 2, 0, "TabButton");
@@ -109,6 +122,7 @@ void QtQuickControls2Plugin::registerTypes(const char *uri)
qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("ToggleButton.qml"))), uri, 2, 0, "ToggleButton");
qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("ToolBar.qml"))), uri, 2, 0, "ToolBar");
qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("ToolButton.qml"))), uri, 2, 0, "ToolButton");
+ qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("Tumbler.qml"))), uri, 2, 0, "Tumbler");
}
void QtQuickControls2Plugin::initializeEngine(QQmlEngine *engine, const char *uri)
diff --git a/src/imports/extras/doc/images/.directory b/src/imports/extras/doc/images/.directory
deleted file mode 100644
index 7d49c166..00000000
--- a/src/imports/extras/doc/images/.directory
+++ /dev/null
@@ -1,4 +0,0 @@
-[Dolphin]
-Timestamp=2015,7,13,18,47,2
-Version=3
-ViewMode=1
diff --git a/src/imports/extras/doc/qtquickextras2.qdocconf b/src/imports/extras/doc/qtquickextras2.qdocconf
deleted file mode 100644
index 622c7d05..00000000
--- a/src/imports/extras/doc/qtquickextras2.qdocconf
+++ /dev/null
@@ -1,47 +0,0 @@
-include($QT_INSTALL_DOCS/global/qt-module-defaults.qdocconf)
-
-project = QtQuickExtras2
-description = Qt Quick Extras 2 Reference Documentation
-version = $QT_VERSION
-
-qhp.projects = QtQuickExtras2
-
-qhp.QtQuickExtras2.file = qtquickextras2.qhp
-qhp.QtQuickExtras2.namespace = org.qt-project.qtquickextras2.$QT_VERSION_TAG
-qhp.QtQuickExtras2.virtualFolder = qtquickextras2
-qhp.QtQuickExtras2.indexTitle = Qt Quick Extras 2
-qhp.QtQuickExtras2.indexRoot =
-
-qhp.QtQuickExtras2.filterAttributes = qtquickextras2 $QT_VERSION qtrefdoc
-qhp.QtQuickExtras2.customFilters.Qt.name = QtQuickExtras2 $QT_VERSION
-qhp.QtQuickExtras2.customFilters.Qt.filterAttributes = qtquickextras2 $QT_VERSION
-
-qhp.QtQuickExtras2.subprojects = qtquickextras2qmltypes
-
-qhp.QtQuickExtras2.subprojects.qtquickextras2qmltypes.title = Extras 2 QML Types
-qhp.QtQuickExtras2.subprojects.qtquickextras2qmltypes.indexTitle = Qt Quick Extras 2 QML Types
-qhp.QtQuickExtras2.subprojects.qtquickextras2qmltypes.selectors = qmlclass
-qhp.QtQuickExtras2.subprojects.qtquickextras2qmltypes.sortPages = true
-
-depends = qtcore qtgui qtdoc qtqml qtquick qtquicklayouts qtquickdialogs qtquickcontrols2
-
-# Specify the install path under QT_INSTALL_EXAMPLES
-# Examples will be installed under quick/extras - 'extras' subdirectory
-# is given as part of \example commands
-exampledirs += ../ ../../../../examples/quick/extras
-examplesinstallpath = quick/extras
-
-headerdirs += ../
-sourcedirs += ../
-
-imagedirs += images
-
-navigation.landingpage = "Qt Quick Extras 2"
-navigation.qmltypespage = "Qt Quick Extras 2 QML Types"
-
-tagfile = qtquickextras2.tags
-
-# Specify a QML module suffix, applied to html filenames, to avoid
-# clashes with Qt Quick Extras 1 documentation.
-outputsuffixes = QML
-outputsuffixes.QML = 2
diff --git a/src/imports/extras/doc/src/qtquickextras2-customize.qdoc b/src/imports/extras/doc/src/qtquickextras2-customize.qdoc
deleted file mode 100644
index fc04fe1f..00000000
--- a/src/imports/extras/doc/src/qtquickextras2-customize.qdoc
+++ /dev/null
@@ -1,82 +0,0 @@
-/****************************************************************************
-**
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
-**
-** This file is part of the documentation of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:FDL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
-**
-** GNU Free Documentation License Usage
-** Alternatively, this file may be used under the terms of the GNU Free
-** Documentation License version 1.3 as published by the Free Software
-** Foundation and appearing in the file included in the packaging of
-** this file. Please review the following information to ensure
-** the GNU Free Documentation License version 1.3 requirements
-** will be met: http://www.gnu.org/copyleft/fdl.html.
-** $QT_END_LICENSE$
-**
-****************************************************************************/
-
-/*!
- \page qtquickextras2-customize.html
- \title Customizing Qt Quick Extras 2
- \brief A set of UI controls to create user interfaces in Qt Quick
-
- Qt Quick Controls consist of a hierarchy (tree) of items. In order to
- provide a custom look and feel, the default implementation of each item
- can be replaced with a custom one. The following snippets present the
- default implementations of various items. These can be used as a starting
- point to implement a custom look and feel.
-
- \sa {Customizing Qt Quick Controls 2}
-
- \section1 Customizing Dial
-
- Dial consists of two visual items: \l {Control::background}{background}
- and \l {Dial::handle}{handle}.
-
- \section3 Background
-
- \image qtquickextras2-dial-background.png
-
- \snippet Dial.qml background
-
- \section3 Indicator
-
- \image qtquickextras2-dial-handle.png
-
- \snippet Dial.qml handle
-
- \section1 Customizing Tumbler
-
- Tumbler consists of three visual items:
- \l {Control::background}{background},
- \l {Control::contentItem}{contentItem}, and
- \l {Tumbler::delegate}{delegate}.
-
- \section3 Background
-
- \image qtquickextras2-tumbler-background.png
-
- Tumbler has no background item by default.
-
- \section3 Content Item
-
- \image qtquickextras2-tumbler-contentItem.png
-
- \snippet Tumbler.qml contentItem
-
- \section3 Delegate
-
- \image qtquickextras2-tumbler-delegate.png
-
- \snippet Tumbler.qml delegate
-*/
diff --git a/src/imports/extras/doc/src/qtquickextras2-index.qdoc b/src/imports/extras/doc/src/qtquickextras2-index.qdoc
deleted file mode 100644
index 53712e22..00000000
--- a/src/imports/extras/doc/src/qtquickextras2-index.qdoc
+++ /dev/null
@@ -1,49 +0,0 @@
-/****************************************************************************
-**
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
-**
-** This file is part of the documentation of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:FDL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
-**
-** GNU Free Documentation License Usage
-** Alternatively, this file may be used under the terms of the GNU Free
-** Documentation License version 1.3 as published by the Free Software
-** Foundation and appearing in the file included in the packaging of
-** this file. Please review the following information to ensure
-** the GNU Free Documentation License version 1.3 requirements
-** will be met: http://www.gnu.org/copyleft/fdl.html.
-** $QT_END_LICENSE$
-**
-****************************************************************************/
-
-/*!
- \page qtquickextras2-index.html
- \title Qt Quick Extras 2
-
- \brief The Qt Quick Extras 2 module provides a set of specialized UI
- controls for Qt Quick.
-
- The Qt Quick Extras 2 module provides a set of controls that can be used to
- build interfaces in Qt Quick.
-
- The module is new in Qt 5.6.
-
- Visit the \l{Qt Quick Extras 2 Overview} page to get started.
-
- \section1 Related Information
-
- \list
- \li \l{Qt Quick}
- \li \l{Qt Quick Extras 2 Overview}
- \li \l{Qt Quick Extras 2 QML Types}{Qt Quick Extras 2 QML Types}
- \endlist
-*/
diff --git a/src/imports/extras/doc/src/qtquickextras2-overview.qdoc b/src/imports/extras/doc/src/qtquickextras2-overview.qdoc
deleted file mode 100644
index 9776e1de..00000000
--- a/src/imports/extras/doc/src/qtquickextras2-overview.qdoc
+++ /dev/null
@@ -1,53 +0,0 @@
-/****************************************************************************
-**
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
-**
-** This file is part of the documentation of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:FDL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
-**
-** GNU Free Documentation License Usage
-** Alternatively, this file may be used under the terms of the GNU Free
-** Documentation License version 1.3 as published by the Free Software
-** Foundation and appearing in the file included in the packaging of
-** this file. Please review the following information to ensure
-** the GNU Free Documentation License version 1.3 requirements
-** will be met: http://www.gnu.org/copyleft/fdl.html.
-** $QT_END_LICENSE$
-**
-****************************************************************************/
-
-/*!
- \page qtquickextras2-overview.html
- \title Qt Quick Extras 2 Overview
- \brief A set of UI controls to create user interfaces in Qt Quick
-
- The Qt Quick Extras 2 module provides a set of UI controls to create user
- interfaces in Qt Quick.
-
- \section1 Getting Started
-
- TODO
-
- \section1 Customization
-
- Qt Quick Controls consist of a hierarchy (tree) of items. In order to
- provide a custom look and feel, the default implementation of each can be
- replaced with a custom item. For examples of how do this, see
- \l {Customizing Qt Quick Extras 2}.
-
- \section1 Related Information
-
- \list
- \li \l{Qt Quick}
- \li \l{Qt Quick Controls 2}
- \endlist
-*/
diff --git a/src/imports/extras/doc/src/qtquickextras2.qdoc b/src/imports/extras/doc/src/qtquickextras2.qdoc
deleted file mode 100644
index 74dbd778..00000000
--- a/src/imports/extras/doc/src/qtquickextras2.qdoc
+++ /dev/null
@@ -1,44 +0,0 @@
-/****************************************************************************
-**
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
-**
-** This file is part of the documentation of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:FDL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
-**
-** GNU Free Documentation License Usage
-** Alternatively, this file may be used under the terms of the GNU Free
-** Documentation License version 1.3 as published by the Free Software
-** Foundation and appearing in the file included in the packaging of
-** this file. Please review the following information to ensure
-** the GNU Free Documentation License version 1.3 requirements
-** will be met: http://www.gnu.org/copyleft/fdl.html.
-** $QT_END_LICENSE$
-**
-****************************************************************************/
-
-/*!
- \qmlmodule QtQuick.Extras 2.0
- \title Qt Quick Extras 2 QML Types
- \ingroup qmlmodules
- \brief Provides QML types for user interfaces.
-
- The \l{Qt Quick Extras 2} module provides QML types for creating user
- interfaces. These QML types work in conjunction with \l{Qt Quick},
- \l{Qt Quick Layouts} and \l{Qt Quick Controls 2}.
-
- The QML types can be imported into your application using the
- following import statement in your .qml file.
-
- \badcode
- import QtQuick.Extras 2.0
- \endcode
-*/
diff --git a/src/imports/extras/extras.pri b/src/imports/extras/extras.pri
deleted file mode 100644
index 859ed07e..00000000
--- a/src/imports/extras/extras.pri
+++ /dev/null
@@ -1,17 +0,0 @@
-QML_FILES = \
- Dial.qml \
- Drawer.qml \
- SwipeView.qml \
- Tumbler.qml
-
-HEADERS += \
- $$PWD/qquickdial_p.h \
- $$PWD/qquickdrawer_p.h \
- $$PWD/qquickswipeview_p.h \
- $$PWD/qquicktumbler_p.h
-
-SOURCES += \
- $$PWD/qquickdial.cpp \
- $$PWD/qquickdrawer.cpp \
- $$PWD/qquickswipeview.cpp \
- $$PWD/qquicktumbler.cpp
diff --git a/src/imports/extras/extras.pro b/src/imports/extras/extras.pro
deleted file mode 100644
index fd3dcc1e..00000000
--- a/src/imports/extras/extras.pro
+++ /dev/null
@@ -1,23 +0,0 @@
-TARGET = qtquickextras2plugin
-TARGETPATH = QtQuick/Extras.2
-IMPORT_VERSION = 2.0
-
-QT += qml quick
-QT += core-private gui-private qml-private quick-private quicktemplates-private
-
-QMAKE_DOCS = $$PWD/doc/qtquickextras2.qdocconf
-
-DEFINES += QT_NO_CAST_TO_ASCII QT_NO_CAST_FROM_ASCII
-
-INCLUDEPATH += $$PWD
-
-OTHER_FILES += \
- qmldir
-
-SOURCES += \
- $$PWD/qtquickextras2plugin.cpp
-
-include(extras.pri)
-
-CONFIG += no_cxx_module
-load(qml_plugin)
diff --git a/src/imports/extras/plugins.qmltypes b/src/imports/extras/plugins.qmltypes
deleted file mode 100644
index 9741b463..00000000
--- a/src/imports/extras/plugins.qmltypes
+++ /dev/null
@@ -1,67 +0,0 @@
-import QtQuick.tooling 1.2
-
-// This file describes the plugin-supplied types contained in the library.
-// It is used for QML tooling purposes only.
-//
-// This file was auto-generated by:
-// 'qmlplugindump -nonrelocatable QtQuick.Extras 2.0'
-
-Module {
- dependencies: [
- "QtQuick 2.6",
- "QtQuick.Controls 2.0",
- "QtQuick.Window 2.2"
- ]
- Component {
- name: "QQuickDrawer"
- defaultProperty: "contentItem"
- prototype: "QQuickControl"
- exports: ["QtQuick.Extras/AbstractDrawer 2.0"]
- exportMetaObjectRevisions: [0]
- Property { name: "edge"; type: "Qt::Edge" }
- Property { name: "position"; type: "double" }
- Property { name: "contentItem"; type: "QQuickItem"; isPointer: true }
- Property { name: "animation"; type: "QQuickPropertyAnimation"; isPointer: true }
- Signal { name: "clicked" }
- Method { name: "open" }
- Method { name: "close" }
- }
- Component {
- name: "QQuickSwipeView"
- defaultProperty: "contentData"
- prototype: "QQuickContainer"
- exports: ["QtQuick.Extras/AbstractSwipeView 2.0"]
- exportMetaObjectRevisions: [0]
- Property { name: "count"; type: "int"; isReadonly: true }
- Property { name: "currentIndex"; type: "int" }
- Property { name: "model"; type: "QVariant"; isReadonly: true }
- Property { name: "contentData"; type: "QObject"; isList: true; isReadonly: true }
- Method {
- name: "setCurrentIndex"
- Parameter { name: "index"; type: "int" }
- }
- Method {
- name: "itemAt"
- type: "QQuickItem*"
- Parameter { name: "index"; type: "int" }
- }
- Method {
- name: "addItem"
- Parameter { name: "item"; type: "QQuickItem"; isPointer: true }
- }
- Method {
- name: "insertItem"
- Parameter { name: "index"; type: "int" }
- Parameter { name: "item"; type: "QQuickItem"; isPointer: true }
- }
- Method {
- name: "moveItem"
- Parameter { name: "from"; type: "int" }
- Parameter { name: "to"; type: "int" }
- }
- Method {
- name: "removeItem"
- Parameter { name: "index"; type: "int" }
- }
- }
-}
diff --git a/src/imports/extras/qmldir b/src/imports/extras/qmldir
deleted file mode 100644
index 8822d83b..00000000
--- a/src/imports/extras/qmldir
+++ /dev/null
@@ -1,3 +0,0 @@
-module QtQuick.Extras
-plugin qtquickextras2plugin
-classname QtQuickExtras2Plugin
diff --git a/src/imports/extras/qtquickextras2plugin.cpp b/src/imports/extras/qtquickextras2plugin.cpp
deleted file mode 100644
index e0208e7a..00000000
--- a/src/imports/extras/qtquickextras2plugin.cpp
+++ /dev/null
@@ -1,74 +0,0 @@
-/****************************************************************************
-**
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
-**
-** This file is part of the Qt Quick Extras module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL3$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPLv3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or later as published by the Free
-** Software Foundation and appearing in the file LICENSE.GPL included in
-** the packaging of this file. Please review the following information to
-** ensure the GNU General Public License version 2.0 requirements will be
-** met: http://www.gnu.org/licenses/gpl-2.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
-
-#include <QtQml/qqmlextensionplugin.h>
-#include <QtCore/qdir.h>
-
-#include "qquickdial_p.h"
-#include "qquickdrawer_p.h"
-#include "qquickswipeview_p.h"
-#include "qquicktumbler_p.h"
-
-QT_BEGIN_NAMESPACE
-
-class QtQuickExtras2Plugin: public QQmlExtensionPlugin
-{
- Q_OBJECT
- Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface/1.0")
-
-public:
- void registerTypes(const char *uri);
-};
-
-void QtQuickExtras2Plugin::registerTypes(const char *uri)
-{
- qmlRegisterType<QQuickDial>(uri, 2, 0, "AbstractDial");
- qmlRegisterType<QQuickDrawer>(uri, 2, 0, "AbstractDrawer");
- qmlRegisterType<QQuickSwipeView>(uri, 2, 0, "AbstractSwipeView");
- qmlRegisterType<QQuickSwipeViewAttached>();
- qmlRegisterType<QQuickTumbler>(uri, 2, 0, "AbstractTumbler");
- qmlRegisterType<QQuickTumblerAttached>();
-
- QDir baseDir(baseUrl().toLocalFile());
- qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("Dial.qml"))), uri, 2, 0, "Dial");
- qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("Drawer.qml"))), uri, 2, 0, "Drawer");
- qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("SwipeView.qml"))), uri, 2, 0, "SwipeView");
- qmlRegisterType(QUrl::fromLocalFile(baseDir.filePath(QStringLiteral("Tumbler.qml"))), uri, 2, 0, "Tumbler");
-}
-
-QT_END_NAMESPACE
-
-#include "qtquickextras2plugin.moc"
diff --git a/src/imports/imports.pro b/src/imports/imports.pro
index aca40893..7a5e5bf5 100644
--- a/src/imports/imports.pro
+++ b/src/imports/imports.pro
@@ -2,5 +2,4 @@ TEMPLATE = subdirs
SUBDIRS += \
controls \
calendar \
- extras \
templates
diff --git a/src/imports/extras/qquickdial.cpp b/src/imports/controls/qquickdial.cpp
index aa93e9ca..407899d3 100644
--- a/src/imports/extras/qquickdial.cpp
+++ b/src/imports/controls/qquickdial.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing/
**
** This file is part of the Qt Quick Extras module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
@@ -46,7 +46,7 @@ QT_BEGIN_NAMESPACE
\qmltype Dial
\inherits Control
\instantiates QQuickDial
- \inqmlmodule QtQuick.Extras
+ \inqmlmodule QtQuick.Controls
\ingroup sliders
\brief A circular dial that is rotated to set a value.
@@ -167,7 +167,7 @@ QQuickDial::QQuickDial(QQuickItem *parent) :
}
/*!
- \qmlproperty real QtQuickExtras2::Dial::from
+ \qmlproperty real QtQuickControls2::Dial::from
This property holds the starting value for the range. The default value is \c 0.0.
@@ -193,7 +193,7 @@ void QQuickDial::setFrom(qreal from)
}
/*!
- \qmlproperty real QtQuickExtras2::Dial::to
+ \qmlproperty real QtQuickControls2::Dial::to
This property holds the end value for the range. The default value is
\c 1.0.
@@ -220,7 +220,7 @@ void QQuickDial::setTo(qreal to)
}
/*!
- \qmlproperty real QtQuickExtras2::Dial::value
+ \qmlproperty real QtQuickControls2::Dial::value
This property holds the value in the range \c from - \c to. The default
value is \c 0.0.
@@ -251,7 +251,7 @@ void QQuickDial::setValue(qreal value)
}
/*!
- \qmlproperty real QtQuickExtras2::Dial::position
+ \qmlproperty real QtQuickControls2::Dial::position
This property holds the logical position of the handle.
@@ -269,7 +269,7 @@ qreal QQuickDial::position() const
}
/*!
- \qmlproperty real QtQuickExtras2::Dial::angle \readonly
+ \qmlproperty real QtQuickControls2::Dial::angle \readonly
This property holds the angle of the handle.
@@ -285,7 +285,7 @@ qreal QQuickDial::angle() const
}
/*!
- \qmlproperty real QtQuickExtras2::Dial::stepSize
+ \qmlproperty real QtQuickControls2::Dial::stepSize
This property holds the step size. The default value is \c 0.0.
@@ -307,7 +307,7 @@ void QQuickDial::setStepSize(qreal step)
}
/*!
- \qmlproperty enumeration QtQuickExtras2::Dial::snapMode
+ \qmlproperty enumeration QtQuickControls2::Dial::snapMode
This property holds the snap mode.
@@ -339,7 +339,7 @@ void QQuickDial::setSnapMode(SnapMode mode)
}
/*!
- \qmlproperty bool QtQuickExtras2::Dial::pressed
+ \qmlproperty bool QtQuickControls2::Dial::pressed
This property holds whether the dial is pressed.
@@ -372,7 +372,7 @@ void QQuickDial::setPressed(bool pressed)
}
/*!
- \qmlmethod void QtQuickExtras2::Dial::increase()
+ \qmlmethod void QtQuickControls2::Dial::increase()
Increases the value by \l stepSize, or \c 0.1 if stepSize is not defined.
@@ -386,7 +386,7 @@ void QQuickDial::increase()
}
/*!
- \qmlmethod void QtQuickExtras2::Dial::decrease()
+ \qmlmethod void QtQuickControls2::Dial::decrease()
Decreases the value by \l stepSize, or \c 0.1 if stepSize is not defined.
@@ -400,7 +400,7 @@ void QQuickDial::decrease()
}
/*!
- \qmlproperty component QtQuickExtras2::Dial::handle
+ \qmlproperty component QtQuickControls2::Dial::handle
This property holds the handle of the dial.
@@ -3,7 +3,7 @@
** Contact: http://www.qt.io/licensing/
**
-** This file is part of the Qt Quick Extras module of the Qt Toolkit.
+** This file is part of the Qt Quick Controls module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
diff --git a/src/imports/extras/qquickswipeview.cpp b/src/imports/controls/qquickswipeview.cpp
index bb89f9fd..f86e8c8c 100644
--- a/src/imports/extras/qquickswipeview.cpp
+++ b/src/imports/controls/qquickswipeview.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing/
**
** This file is part of the Qt Quick Extras module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
@@ -44,7 +44,7 @@ QT_BEGIN_NAMESPACE
\qmltype SwipeView
\inherits Container
\instantiates QQuickSwipeView
- \inqmlmodule QtQuick.Extras
+ \inqmlmodule QtQuick.Controls
\ingroup navigation
\brief A swipe view control.
@@ -149,7 +149,7 @@ void QQuickSwipeView::contentItemChange(QQuickItem *newItem, QQuickItem *oldItem
}
/*!
- \qmlattachedproperty int QtQuickExtras2::SwipeView::index
+ \qmlattachedproperty int QtQuickControls2::SwipeView::index
This attached property holds the index of each child item in the SwipeView.
@@ -157,7 +157,7 @@ void QQuickSwipeView::contentItemChange(QQuickItem *newItem, QQuickItem *oldItem
*/
/*!
- \qmlattachedproperty bool QtQuickExtras2::SwipeView::isCurrentItem
+ \qmlattachedproperty bool QtQuickControls2::SwipeView::isCurrentItem
This attached property is \c true if this child is the current item.
@@ -165,7 +165,7 @@ void QQuickSwipeView::contentItemChange(QQuickItem *newItem, QQuickItem *oldItem
*/
/*!
- \qmlattachedproperty SwipeView QtQuickExtras2::SwipeView::view
+ \qmlattachedproperty SwipeView QtQuickControls2::SwipeView::view
This attached property holds the view that manages this child item.
@@ -3,7 +3,7 @@
** Contact: http://www.qt.io/licensing/
**
-** This file is part of the Qt Quick Extras module of the Qt Toolkit.
+** This file is part of the Qt Quick Controls module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
diff --git a/src/imports/extras/qquicktumbler.cpp b/src/imports/controls/qquicktumbler.cpp
index dd24693b..9f53f92e 100644
--- a/src/imports/extras/qquicktumbler.cpp
+++ b/src/imports/controls/qquicktumbler.cpp
@@ -3,7 +3,7 @@
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing/
**
** This file is part of the Qt Quick Extras module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
@@ -45,7 +45,7 @@ QT_BEGIN_NAMESPACE
\qmltype Tumbler
\inherits Control
\instantiates QQuickTumbler
- \inqmlmodule QtQuick.Extras
+ \inqmlmodule QtQuick.Controls
\ingroup containers
\brief A spinnable wheel of items that can be selected.
@@ -63,7 +63,7 @@ QT_BEGIN_NAMESPACE
\snippet tst_tumbler.qml contentItem
- \image qtquickextras2-tumbler-wrap.gif
+ \image qtquickcontrols2-tumbler-wrap.gif
*/
class QQuickTumblerPrivate : public QQuickControlPrivate, public QQuickItemChangeListener
@@ -193,7 +193,7 @@ QQuickTumbler::~QQuickTumbler()
}
/*!
- \qmlproperty variant QtQuickExtras2::Tumbler::model
+ \qmlproperty variant QtQuickControls2::Tumbler::model
This property holds the model that provides data for this tumbler.
*/
@@ -213,7 +213,7 @@ void QQuickTumbler::setModel(const QVariant &model)
}
/*!
- \qmlproperty int QtQuickExtras2::Tumbler::count
+ \qmlproperty int QtQuickControls2::Tumbler::count
This property holds the number of items in the model.
*/
@@ -224,7 +224,7 @@ int QQuickTumbler::count() const
}
/*!
- \qmlproperty int QtQuickExtras2::Tumbler::currentIndex
+ \qmlproperty int QtQuickControls2::Tumbler::currentIndex
This property holds the index of the current item.
*/
@@ -241,7 +241,7 @@ void QQuickTumbler::setCurrentIndex(int currentIndex)
}
/*!
- \qmlproperty Item QtQuickExtras2::Tumbler::currentItem
+ \qmlproperty Item QtQuickControls2::Tumbler::currentItem
This property holds the item at the current index.
*/
@@ -252,7 +252,7 @@ QQuickItem *QQuickTumbler::currentItem() const
}
/*!
- \qmlproperty component QtQuickExtras2::Tumbler::delegate
+ \qmlproperty component QtQuickControls2::Tumbler::delegate
This property holds the delegate used to display each item.
*/
@@ -272,7 +272,7 @@ void QQuickTumbler::setDelegate(QQmlComponent *delegate)
}
/*!
- \qmlproperty int QtQuickExtras2::Tumbler::visibleItemCount
+ \qmlproperty int QtQuickControls2::Tumbler::visibleItemCount
This property holds the number of items visible in the tumbler. It must be
an odd number, as the current item is always vertically centered.
@@ -3,7 +3,7 @@
** Contact: http://www.qt.io/licensing/
**
-** This file is part of the Qt Quick Extras module of the Qt Toolkit.
+** This file is part of the Qt Quick Controls module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$